@@ -33,7 +33,7 @@
 #endif
 
 void UpdateTraceSelection(Trptr t);
-
+int traverse_vector_nodes(Trptr t);
 
 /*
  * extract last n levels of hierarchy
@@ -1493,8 +1493,11 @@ if((underflow_sticky) || (oc_cnt > 0))
 }
 
 /*
- * $Id: analyzer.c,v 1.26 2010/04/15 00:30:23 gtkwave Exp $
+ * $Id: analyzer.c,v 1.27 2010/06/23 05:45:34 gtkwave Exp $
  * $Log: analyzer.c,v $
+ * Revision 1.27  2010/06/23 05:45:34  gtkwave
+ * warnings fixes
+ *
  * Revision 1.26  2010/04/15 00:30:23  gtkwave
  * don't propagate ttranslate filter into groups
  *
