@@ -7,6 +7,7 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
 #include <config.h>
 #include "currenttime.h"
 #include "pixmaps.h"
@@ -29,9 +30,9 @@ GtkTooltips *tooltips;
 tooltips=gtk_tooltips_new_2();
 gtk_tooltips_set_delay_2(tooltips,1500);
 
-pixmapwid1=gtk_pixmap_new(larrow_pixmap, larrow_mask);
+pixmapwid1=gtk_pixmap_new(GLOBALS->larrow_pixmap, GLOBALS->larrow_mask);
 gtk_widget_show(pixmapwid1);
-pixmapwid2=gtk_pixmap_new(rarrow_pixmap, rarrow_mask);
+pixmapwid2=gtk_pixmap_new(GLOBALS->rarrow_pixmap, GLOBALS->rarrow_mask);
 gtk_widget_show(pixmapwid2);
    
 /* Create a table to hold the text widget and scrollbars */
@@ -54,8 +55,7 @@ gtk_container_add(GTK_CONTAINER(b1), pixmapwid1);
 gtk_table_attach (GTK_TABLE (table2), b1, 0, 1, 0, 1,
 			GTK_FILL | GTK_EXPAND,
 		      	GTK_FILL | GTK_EXPAND | GTK_SHRINK, 1, 1);
-gtk_signal_connect_object (GTK_OBJECT (b1), "clicked",
-              		GTK_SIGNAL_FUNC(discard_left), GTK_OBJECT (table2));
+gtk_signal_connect_object (GTK_OBJECT (b1), "clicked", GTK_SIGNAL_FUNC(discard_left), GTK_OBJECT (table2));
 gtk_tooltips_set_tip_2(tooltips, b1, "Increase 'From' Time", NULL);
 gtk_widget_show(b1);
 
@@ -64,8 +64,7 @@ gtk_container_add(GTK_CONTAINER(b2), pixmapwid2);
 gtk_table_attach (GTK_TABLE (table2), b2, 0, 1, 1, 2,
 		      	GTK_FILL | GTK_EXPAND,
 		      	GTK_FILL | GTK_EXPAND | GTK_SHRINK, 1, 1);
-gtk_signal_connect_object (GTK_OBJECT (b2), "clicked",
-               		GTK_SIGNAL_FUNC(discard_right), GTK_OBJECT (table2));
+gtk_signal_connect_object (GTK_OBJECT (b2), "clicked", GTK_SIGNAL_FUNC(discard_right), GTK_OBJECT (table2));
 gtk_tooltips_set_tip_2(tooltips, b2, "Decrease 'To' Time", NULL);
 gtk_widget_show(b2);
 
@@ -75,8 +74,30 @@ return(table);
 }
    
 /*
- * $Id: discardbuttons.c,v 1.2 2007/04/20 02:08:11 gtkwave Exp $
+ * $Id: discardbuttons.c,v 1.4 2007/09/12 19:24:45 gtkwave Exp $
  * $Log: discardbuttons.c,v $
+ * Revision 1.4  2007/09/12 19:24:45  gtkwave
+ * more ctx_swap_watchdog updates
+ *
+ * Revision 1.3  2007/09/12 17:26:44  gtkwave
+ * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
+ *
+ * Revision 1.2  2007/08/26 21:35:40  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.3  2007/08/07 03:18:54  kermin
+ * Changed to pointer based GLOBAL structure and added initialization function
+ *
+ * Revision 1.1.1.1.2.2  2007/08/06 03:50:45  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:19  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:28:00  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:11  gtkwave
  * initial release
  *
