@@ -12,7 +12,7 @@
 #ifndef WAVE_FSTRDR_H
 #define WAVE_FSTRDR_H
 
-#ifndef _MSC_VER
+#ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
 #endif
 
@@ -27,8 +27,11 @@ void fst_import_masked(void);
 #endif
 
 /*
- * $Id: fst.h,v 1.1 2009/08/06 20:03:15 gtkwave Exp $
+ * $Id: fst.h,v 1.2 2010/04/27 23:10:56 gtkwave Exp $
  * $Log: fst.h,v $
+ * Revision 1.2  2010/04/27 23:10:56  gtkwave
+ * made inttype.h inclusion conditional
+ *
  * Revision 1.1  2009/08/06 20:03:15  gtkwave
  * creation
  *
