@@ -24,13 +24,22 @@
 #define WAVE_GTK_WAVEFONT wavearea->style->font
 #define WAVE_GTK_SFUNCAST(x) ((GtkSignalFunc)(x))
 
+#define gtk_notebook_set_current_page(n,p) gtk_notebook_set_page((n),(p))
+
+
 #endif
 
 #endif
 
 /*
- * $Id: gtk12compat.h,v 1.2 2007/04/20 02:08:13 gtkwave Exp $
+ * $Id: gtk12compat.h,v 1.2 2007/09/10 19:43:20 gtkwave Exp $
  * $Log: gtk12compat.h,v $
+ * Revision 1.2  2007/09/10 19:43:20  gtkwave
+ * gtk1.2 compile fixes
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:58  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:13  gtkwave
  * initial release
  *
