@@ -161,6 +161,8 @@ WV_MENU_ACOL,
 WV_MENU_ACOLR,
 WV_MENU_ABON,
 WV_MENU_HTGP,
+WV_MENU_SEP7C,
+WV_MENU_STRSE,
 WV_MENU_TMTT,
 WV_MENU_TZZA,
 WV_MENU_TZZB,
@@ -349,8 +351,11 @@ bvptr combine_traces(int direction, Trptr single_trace_only);
 #endif
 
 /*
- * $Id: menu.h,v 1.36 2010/04/12 23:07:12 gtkwave Exp $
+ * $Id: menu.h,v 1.37 2010/06/13 20:38:00 gtkwave Exp $
  * $Log: menu.h,v $
+ * Revision 1.37  2010/06/13 20:38:00  gtkwave
+ * added strace repeat count
+ *
  * Revision 1.36  2010/04/12 23:07:12  gtkwave
  * add ability to make single signals transactions
  *
