@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2003.
+ * Copyright (c) Tony Bybell 1999-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,6 +20,15 @@
 #include "currenttime.h"
 #include "bsearch.h"
 
+#if WAVE_USE_GTK2
+#define WAVE_NUM_STRACE_WINDOWS (2)
+#else
+#define WAVE_NUM_STRACE_WINDOWS (1)
+#endif
+
+#define WAVE_STRACE_ITERATOR(x) for((x)=((WAVE_NUM_STRACE_WINDOWS)-1); (x)>=0 ; (x)--)
+#define WAVE_STRACE_ITERATOR_FWD(x) for((x)=0;(x)<(WAVE_NUM_STRACE_WINDOWS);(x)++)
+
 enum strace_directions
 { STRACE_BACKWARD, STRACE_FORWARD };
 
@@ -75,6 +84,36 @@ struct item_mark_string {
    unsigned char idx;
 };
 
+
+/* for being able to handle multiple strace sessions at once, context is moved here */
+struct strace_ctx_t
+{
+GtkWidget *ptr_mark_count_label_strace_c_1; 
+struct strace *straces; 
+struct strace *shadow_straces; 
+struct strace_defer_free *strace_defer_free_head; 
+GtkWidget *window_strace_c_10; 
+void (*cleanup_strace_c_7)(); 
+
+struct mprintf_buff_t *mprintf_buff_head; 
+struct mprintf_buff_t *mprintf_buff_current; 
+char *shadow_string; 
+
+TimeType *timearray; 
+int timearray_size; 
+
+char logical_mutex[6]; 
+char shadow_logical_mutex[6]; 
+char shadow_active; 
+char shadow_encountered_parsewavline; 
+char shadow_type; 
+signed char mark_idx_start; 
+signed char mark_idx_end; 
+signed char shadow_mark_idx_start; 
+signed char shadow_mark_idx_end; 
+};
+
+
 void strace_search(int direction);
 void strace_maketimetrace(int mode); /* 1=create, zero=delete */
 TimeType strace_adjust(TimeType a, TimeType b);
@@ -91,8 +130,20 @@ void delete_mprintf(void);
 #endif
 
 /*
- * $Id: strace.h,v 1.4 2008/10/17 14:42:35 gtkwave Exp $
+ * $Id: strace.h,v 1.8 2010/02/24 17:35:35 gtkwave Exp $
  * $Log: strace.h,v $
+ * Revision 1.8  2010/02/24 17:35:35  gtkwave
+ * gtk1 compile fixes
+ *
+ * Revision 1.7  2010/01/22 22:30:14  gtkwave
+ * reordering of strace_ctx_t
+ *
+ * Revision 1.6  2010/01/22 16:51:21  gtkwave
+ * fixes to ensure WAVE_NUM_STRACE_WINDOWS is more maintainable
+ *
+ * Revision 1.5  2010/01/22 02:10:49  gtkwave
+ * added second pattern search capability
+ *
  * Revision 1.4  2008/10/17 14:42:35  gtkwave
  * added findNextEdge/findPrevEdge to tcl interpreter
  *
