@@ -335,7 +335,6 @@ int max_len = 1;
 char *row_data = NULL;
 struct lt_trace *lt = NULL;
 int lxt = (export_typ == WAVE_EXPORT_LXT);
-int seqn = 0;
 
 if(export_typ == WAVE_EXPORT_TIM)
 	{
@@ -1517,8 +1516,11 @@ return(errno ? VCDSAV_FILE_ERROR : VCDSAV_OK);
 }
 
 /*
- * $Id: vcd_saver.c,v 1.16 2010/04/01 20:07:35 gtkwave Exp $
+ * $Id: vcd_saver.c,v 1.17 2010/06/23 05:45:34 gtkwave Exp $
  * $Log: vcd_saver.c,v $
+ * Revision 1.17  2010/06/23 05:45:34  gtkwave
+ * warnings fixes
+ *
  * Revision 1.16  2010/04/01 20:07:35  gtkwave
  * timescale multiplier fix for transactions
  *
